CREATE TABLE solomon_class_teachers (teacher_id bigint PRIMARY KEY AUTO_INCREMENT,
groupid bigint REFERENCES groups (groupid) ON DELETE CASCADE,
uid bigint REFERENCES users (uid) ON DELETE CASCADE,
linkid bigint REFERENCES groups_users_link (linkid) ON DELETE CASCADE
);

CREATE TABLE solomon_department_tbl (department_id int PRIMARY KEY AUTO_INCREMENT,
department_nam TEXT NOT NULL, comment TEXT);

CREATE TABLE solomon_txt_level_tbl (txt_level_id int PRIMARY KEY AUTO_INCREMENT,
txt_level_nam TEXT NOT NULL, comment TEXT);

CREATE TABLE solomon_difficulty_tbl (difficulty_id int PRIMARY KEY AUTO_INCREMENT,
difficulty_nam TEXT NOT NULL, comment TEXT);

CREATE TABLE solomon_class_student_tbl (
class_student_id int PRIMARY KEY AUTO_INCREMENT,
uid bigint REFERENCES users (uid) ON DELETE CASCADE,
groupid bigint REFERENCES groups (groupid) ON DELETE CASCADE,
student_comment text,
teacher_comment text,
present int DEFAULT 0,status int DEFAULT 0,
st_status int,
linkid bigint REFERENCES groups_users_link (linkid) ON DELETE CASCADE,
CONSTRAINT solomon_class_student_tbl_uni UNIQUE(uid, groupid)
);

CREATE TABLE solomon_mobile_tbl (
mobile_user_id bigint PRIMARY KEY AUTO_INCREMENT,
usr_id bigint REFERENCES users (uid) ON DELETE CASCADE,
mobile_id character varying(200) UNIQUE,
create_time datetime, update_time datetime
);

CREATE TABLE solomon_subject_tbl (
subject_id int PRIMARY KEY AUTO_INCREMENT,
subject_name text,
credit tinyint,
create_time datetime,
update_time datetime,
subject_explain text,
del_flag character varying(2)
);

CREATE TABLE solomon_subject_type_tbl (
subject_type_id int PRIMARY KEY AUTO_INCREMENT,
subject_type_name text,
credit tinyint,
create_time datetime,
update_time datetime,
subject_type_explain text,
faculty_id int REFERENCES solomon_faculty_tbl (faculty_id) ON DELETE CASCADE,
department_id int REFERENCES solomon_department_tbl (department_id) ON DELETE SET NULL,
txt_level_id int REFERENCES solomon_txt_level_tbl (txt_level_id) ON DELETE SET NULL,
difficulty_id int REFERENCES solomon_difficulty_tbl (difficulty_id) ON DELETE SET NULL
);

CREATE TABLE solomon_faculty_tbl (
faculty_id int PRIMARY KEY AUTO_INCREMENT,
faculty_name text,
faculty_explain text,
create_time datetime,
update_time datetime,
del_flag character varying(2)
);


CREATE TABLE solomon_subject_type_link_tbl (
subject_type_id int REFERENCES solomon_subject_type_tbl (subject_type_id) ON DELETE CASCADE,
subject_id int REFERENCES solomon_subject_tbl (subject_id) ON DELETE CASCADE,
create_time datetime,
CONSTRAINT solomon_subject_type_link_tbl_uni UNIQUE(subject_type_id, subject_id)
);

CREATE TABLE solomon_subject_group_link_tbl (
subject_id int REFERENCES solomon_subject_tbl (subject_id) ON DELETE CASCADE,
groupid int REFERENCES groups (groupid) ON DELETE SET NULL,
start_mon int,
period int,
regist_deadline datetime,
CONSTRAINT solomon_subject_group_link_tbl_uni UNIQUE(groupid, subject_id)
);

CREATE TABLE solomon_subject_application_tbl (
groupid int REFERENCES groups (groupid) ON DELETE SET NULL,
uid int REFERENCES users (uid) ON DELETE CASCADE,
application_time datetime,
CONSTRAINT solomon_subject_application_tbl_uni UNIQUE(groupid, uid)
);

CREATE TABLE solomon_motive_tbl (
motive_id int PRIMARY KEY AUTO_INCREMENT,
motive_text text,
create_time datetime,
update_time datetime
);

CREATE TABLE solomon_user_motive_tbl (
motive_id int REFERENCES solomon_motive_tbl (motive_id) ON DELETE CASCADE,
uid int REFERENCES users (uid) ON DELETE CASCADE,
points character varying (3),
create_time datetime,
update_time datetime
);

CREATE TABLE solomon_user_motive_text_tbl (
uid int REFERENCES users (uid) ON DELETE CASCADE,
motive_text text,
points character varying (3),
create_time datetime,
update_time datetime
);

CREATE TABLE solomon_registed_class_tbl (
group_user_link int PRIMARY KEY REFERENCES groups_users_link (linkid) ON DELETE CASCADE,
uid int REFERENCES users (uid) ON DELETE CASCADE,
get_credit int REFERENCES solomon_credit_tbl (credit_id) ON DELETE SET NULL,
subject_id int REFERENCES solomon_subject_tbl (subject_id) ON DELETE SET NULL,
eval character varying (3),
create_time datetime,
update_time datetime
);

CREATE TABLE solomon_credit_tbl (
credit_id int PRIMARY KEY AUTO_INCREMENT,
credit_name text,
credit_explain text,
is_pass character varying (1),
grade character varying (3),
create_time datetime,
update_time datetime
);


CREATE TABLE solomon_usr_student_add_info_tbl (
uid int REFERENCES users (uid) ON DELETE CASCADE,
faculty_id int REFERENCES solomon_faculty_tbl (faculty_id) ON DELETE CASCADE,
ins_year int,
is_grad character varying (3),
create_time datetime,
update_time datetime,
CONSTRAINT solomon_usr_student_add_uni UNIQUE(faculty_id, uid)
);

CREATE TABLE solomon_usr_staff_add_info_tbl (
uid int REFERENCES users (uid) ON DELETE CASCADE,
faculty_id int REFERENCES solomon_faculty_tbl (faculty_id) ON DELETE CASCADE,
position text,
create_time datetime,
update_time datetime,
CONSTRAINT solomon_usr_staff_add_uni UNIQUE(faculty_id, uid)
);

CREATE TABLE solomon_grad_credit_tbl (
faculty_id int REFERENCES solomon_faculty_tbl (faculty_id) ON DELETE CASCADE,
subject_type_id int REFERENCES solomon_subject_type_tbl (subject_type_id) ON DELETE SET NULL,
credit_num int,
create_time datetime,
update_time datetime,
CONSTRAINT solomon_grad_credit_uni UNIQUE(faculty_id, subject_type_id)
);

CREATE TABLE solomon_usr_credit_tbl (
uid int REFERENCES users (uid) ON DELETE CASCADE,
class_student_id int PRIMARY KEY,
credit_id int REFERENCES solomon_credit_tbl (credit_id) ON DELETE SET NULL,
subject_id int REFERENCES solomon_subject_tbl (subject_id) ON DELETE SET NULL,
get_semester int
);

CREATE TABLE solomon_lec_time_tbl (time_id int PRIMARY KEY AUTO_INCREMENT,
weekday int,
lec_time int
);

CREATE TABLE solomon_lec_time_link_tbl (
weekday int REFERENCES solomon_lec_time_tbl (weekday) ON DELETE CASCADE,
groupid int REFERENCES groups (groupid) ON DELETE CASCADE,
lec_time int,
create_time datetime,
CONSTRAINT solomon_lec_time_uni UNIQUE(weekday, groupid, lec_time)
);

CREATE TABLE solomon_eval_group_tbl (
uid int REFERENCES users (uid) ON DELETE CASCADE,
groupid int REFERENCES groups (groupid) ON DELETE CASCADE,
eval smallint,
create_time datetime,
update_time datetime,
CONSTRAINT solomon_eval_group_uni UNIQUE(uid, groupid)
);

CREATE TABLE solomon_motive_satis_group_tbl (
uid int REFERENCES users (uid) ON DELETE CASCADE,
groupid int REFERENCES groups (groupid) ON DELETE CASCADE,
eval smallint,
teach_eval smallint,
motive_id int REFERENCES solomon_motive_tbl (motive_id),
is_text smallint,
create_time datetime,
update_time datetime,
CONSTRAINT solomon_motive_satis_uni UNIQUE(uid, groupid, motive_id,is_text)
);

CREATE TABLE solomon_add_lec_info_tbl (
groupid int PRIMARY KEY REFERENCES groups (groupid) ON DELETE CASCADE,
lec_explain text,
policy text,
create_time datetime,
update_time datetime
);

CREATE TABLE solomon_lec_motive_tbl (
motive_id int REFERENCES solomon_motive_tbl (motive_id) ON DELETE CASCADE,
groupid int REFERENCES groups (groupid) ON DELETE CASCADE,
points character varying (3),
create_time datetime,
update_time datetime
);

CREATE TABLE solomon_lec_motive_text_tbl (
groupid int REFERENCES groups (groupid) ON DELETE CASCADE,
motive_text text,
points character varying (3),
create_time datetime,
update_time datetime
);

CREATE TABLE solomon_motive_satis_gt_tbl (
student_id int REFERENCES users (uid) ON DELETE CASCADE,
groupid int REFERENCES groups (groupid) ON DELETE CASCADE,
points character varying (3),
tea_id int REFERENCES users (uid) ON DELETE CASCADE,
motive_id int REFERENCES solomon_motive_tbl (motive_id),
is_text tinyint,
satis_comment text,
create_time datetime,
update_time datetime,
CONSTRAINT solomon_motive_satis_gt_uni UNIQUE(student_id, tea_id, groupid, motive_id,is_text)
);

CREATE TABLE solomon_credit_user_tanimoto_tbl (
tanimoto double,
uid1 int REFERENCES users (uid) ,
uid2 int REFERENCES users (uid) ,
create_time datetime);

CREATE TABLE solomon_credit_lec_tanimoto_tbl (
tanimoto double,
subject_id1 int REFERENCES solomon_subject_tbl (subject_id) ,
subject_id2 int REFERENCES solomon_subject_tbl (subject_id) ,
create_time datetime);

CREATE TABLE solomon_eval_tmp_user_avg_tbl (uid int primary key,avg_eval double);

CREATE TABLE solomon_eval_tmp_lec_avg_tbl (groupid int primary key,avg_eval double);

CREATE TABLE solomon_eval_user_pearson_tbl (
uid1 int, uid2 int, pearson_r double,
create_time datetime,
INDEX evalu1(uid1), INDEX evalu2(uid2));

CREATE TABLE solomon_eval_lec_pearson_tbl (
groupid1 int, groupid2 int, pearson_r double,
create_time datetime,
INDEX evalg1(groupid1), INDEX evalg2(groupid2));

CREATE TABLE solomon_eval_lec_reco_tbl (
uid int, groupid int, relation double,
create_time datetime,
INDEX evaluidx(uid), INDEX evalgidx(groupid));

CREATE TABLE solomon_mach_tmp_user_pearson_tbl (
uid1 int, uid2 int, pearson_r double,
create_time datetime,
INDEX mtupu1(uid1), INDEX mtupu2(uid2));

CREATE TABLE solomon_mach_tmp_lec_pearson_tbl (
groupid1 int, groupid2 int, pearson_r double,
create_time datetime,
INDEX mtlpg1(groupid1), INDEX mtlpg2(groupid2));

CREATE TABLE solomon_goal_sim_tmp_user_avg_tbl (uid int, avg_sim double);

CREATE TABLE solomon_goal_sim_tmp_lec_avg_tbl (groupid int, avg_sim double);

CREATE TABLE solomon_goal_sim_tbl (points character varying (3), groupid int, uid int);

CREATE TABLE solomon_rec_mach_lec_tbl (
uid int, groupid int, relation double,
create_time datetime,
INDEX rmuidx(uid), INDEX rmgidx(groupid));

CREATE TABLE solomon_satis_user_pearson_tbl (
uid1 int, uid2 int, pearson_r double,
create_time datetime,
INDEX sup1(uid1), INDEX sup2(uid2));

CREATE TABLE solomon_satis_lec_pearson_tbl (
groupid1 int, groupid2 int, pearson_r double,
create_time datetime,
INDEX slp1(groupid1), INDEX slp2(groupid2));

CREATE TABLE solomon_goal_satis_tbl (points character varying (3), groupid int, uid int);

CREATE TABLE solomon_rec_satis_lec_tbl (uid int, groupid int, relation double, create_time datetime);

CREATE TABLE solomon_rec_calc_status_tbl (
start_time datetime, end_time datetime,status int,
admin_id bigint REFERENCES users (uid),
goal_satis_type int, goal_sims_type int,
eval_sims_type int, credit_sims_type int);

CREATE TABLE solomon_tmp_goal_satis_usr_avg_tbl (uid int, avg_satis double);
CREATE TABLE solomon_tmp_goal_satis_lec_avg_tbl (groupid int, avg_satis double);
